summaryrefslogtreecommitdiffstats
path: root/lib/util/urlutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/urlutil.h')
-rw-r--r--lib/util/urlutil.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/lib/util/urlutil.h b/lib/util/urlutil.h
index e8c84607..39615858 100644
--- a/lib/util/urlutil.h
+++ b/lib/util/urlutil.h
@@ -50,27 +50,27 @@ namespace URLUtil
*/
TQString directory(const TQString & pathName);
/**
* @return The relative path between a parent and child URL, or blank if the specified
* child is not a child of parent.
* @param parent The parent URL.
* @param child The child URL.
* @param slashPolicy If parent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- TQString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const KURL & tqparent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a parent and child URL, or blank if the specified
* child is not a child of parent.
* @param parent The parent URL.
* @param child The child URL.
* @param slashPolicy If parent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- TQString relativePath(const TQString & parent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const TQString & tqparent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a base path and destination path or.
* @param base The base Path.
@@ -133,7 +133,7 @@ namespace URLUtil
TQString extractPathNameRelative(const KURL &baseDirUrl, const KURL &url );
/**Same as above. @p basePath is TQString.*/
TQString extractPathNameRelative(const TQString &basePath, const KURL &url );
- /**Same as above. Both @p basePath and @p absFilePath are QStrings.*/
+ /**Same as above. Both @p basePath and @p absFilePath are TQStrings.*/
TQString extractPathNameRelative(const TQString &basePath, const TQString &absFilePath );
/**
@@ -167,10 +167,10 @@ namespace URLUtil
* @param urls URLs to dump.
* @param aMessage Message to be written onto a stdout.
*/
- void dump( const KURL::List &urls, const TQString &aMessage = TQString::null );
+ void dump( const KURL::List &urls, const TQString &aMessage = TQString() );
/**
- * Same as TQDir::canonicalPath in later versions of Qt. Earlier versions of Qt
+ * Same as TQDir::canonicalPath in later versions of TQt. Earlier versions of TQt
* had this broken, so it's reproduced here.
* Deprecated, use TQDir::canonicalPath instead.
*/
@@ -50,27 +50,27 @@ namespace URLUtil
TQString directory(const TQString & pathName);
/**
- * @return The relative path between a parent and child URL, or blank if the specified
- * child is not a child of parent.
- * @param parent The parent URL.
+ * @return The relative path between a tqparent and child URL, or blank if the specified
+ * child is not a child of tqparent.
+ * @param tqparent The tqparent URL.
* @param child The child URL.
@@ -50,27 +50,27 @@ namespace URLUtil
* @param child The child URL.
- * @param slashPolicy If parent and child are equal then the function returns "/" if
+ * @param slashPolicy If tqparent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
@@ -50,27 +50,27 @@ namespace URLUtil
/**
- * @return The relative path between a parent and child URL, or blank if the specified
- * child is not a child of parent.
- * @param parent The parent URL.
+ * @return The relative path between a tqparent and child URL, or blank if the specified
+ * child is not a child of tqparent.
+ * @param tqparent The tqparent URL.
* @param child The child URL.
@@ -50,27 +50,27 @@ namespace URLUtil
* @param child The child URL.
- * @param slashPolicy If parent and child are equal then the function returns "/" if
+ * @param slashPolicy If tqparent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if